.. _welcome:

PHOXENE's Modbus drivers documentation
======================================

This module is a Python Modbus RTU on serial port driver

It has been developped as Modbus layer for PHOXENE's devices that
implements a serial Modbus communication.

It is mainly used by PHOXENE's applications or devices' drivers

Project page on GitHub: 
https://github.com/Phoxene/phox-modbus

Download page:
https://pypi.org/project/phox-modbus/

Contents:

.. toctree::
   :maxdepth: 2

   presentation
   autodoc
   examples
